# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .text_node import TextNode

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class TextNodeWithScore(pydantic.BaseModel):
    """
    Same as NodeWithScore but type for node is a TextNode instead of BaseNode.
    FastAPI doesn't accept abstract classes like BaseNode.
    """

    node: TextNode
    score: typing.Optional[float]
    class_name: typing.Optional[str]

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}



# This file was auto-generated by Fern from our API Definition.

import typing

from .eval_dataset_execution_config import EvalDatasetExecutionConfig
from .managed_data_source_ingestion_job_config import ManagedDataSourceIngestionJobConfig
from .managed_pipeline_ingestion_job_config import ManagedPipelineIngestionJobConfig
from .run_transform_asset_config import RunTransformAssetConfig

DataSourceManagedIngestionExecutionRunConfigPerOpValue = typing.Union[
    RunTransformAssetConfig,
    EvalDatasetExecutionConfig,
    ManagedPipelineIngestionJobConfig,
    ManagedDataSourceIngestionJobConfig,
]



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

from ..core.datetime_utils import serialize_datetime
from .etl_job_names import EtlJobNames
from .pipeline_managed_ingestion_execution_run_config_per_op_value import (
    PipelineManagedIngestionExecutionRunConfigPerOpValue,
)
from .status_enum import StatusEnum

try:
    import pydantic.v1 as pydantic  # type: ignore
except ImportError:
    import pydantic  # type: ignore


class PipelineManagedIngestionExecution(pydantic.BaseModel):
    """
    Schema for job that executes managed pipeline ingestion over all data-sources linked to a pipeline.
    """

    id: str = pydantic.Field(description="Unique identifier")
    created_at: typing.Optional[dt.datetime] = pydantic.Field(description="Creation datetime")
    updated_at: typing.Optional[dt.datetime] = pydantic.Field(description="Update datetime")
    job_name: EtlJobNames
    status: StatusEnum
    started_at: typing.Optional[dt.datetime]
    ended_at: typing.Optional[dt.datetime]
    run_config_per_op: typing.Dict[str, PipelineManagedIngestionExecutionRunConfigPerOpValue] = pydantic.Field(
        description="Run config that was given to the Dagster job"
    )
    partitions: typing.Optional[typing.Dict[str, str]] = pydantic.Field(description="Partition information")
    pipeline_id: str = pydantic.Field(description="The ID for the Pipeline this execution ran against.")

    def json(self, **kwargs: typing.Any) -> str:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().json(**kwargs_with_defaults)

    def dict(self, **kwargs: typing.Any) -> typing.Dict[str, typing.Any]:
        kwargs_with_defaults: typing.Any = {"by_alias": True, "exclude_unset": True, **kwargs}
        return super().dict(**kwargs_with_defaults)

    class Config:
        frozen = True
        smart_union = True
        json_encoders = {dt.datetime: serialize_datetime}
